import { ElementRef } from '@angular/core';
import { Observable } from 'rxjs';
import { SkyMutationObserverService } from '../mutation/mutation-observer-service';
import { SkyResizeObserverService } from '../resize-observer/resize-observer.service';
import { SkyAppWindowRef } from '../window/window-ref';
import * as i0 from "@angular/core";
export declare class SkyScrollableHostService {
    #private;
    constructor(mutationObserverSvc: SkyMutationObserverService, windowRef: SkyAppWindowRef, resizeObserverSvc?: SkyResizeObserverService);
    /**
     * Returns the given element's current scrollable host
     * @param elementRef The element whose scrollable host is being requested
     * @returns The current scrollable host
     */
    getScrollableHost(elementRef: ElementRef): HTMLElement | Window;
    /**
     * Returns an observable which emits the given element's current scrollable host
     * @param elementRef The element whose scrollable host is being requested
     * @returns An observable which emits the current scrollable host element.
     * @internal
     */
    watchScrollableHost(elementRef: ElementRef): Observable<HTMLElement | Window>;
    /**
     * Returns an observable which emits whenever the element's scrollable host emits a scroll event. The observable will always emit the scroll events from the elements current scrollable host and will update based on any scrollable host changes. The observable will also emit once whenever the scrollable host changes.
     * @param elementRef The element whose scrollable host scroll events are being requested
     * @returns An observable which emits when the elements scrollable host is scrolled or is changed
     */
    watchScrollableHostScrollEvents(elementRef: ElementRef): Observable<void>;
    watchScrollableHostClipPathChanges(elementRef: ElementRef, additionalContainers?: Observable<ElementRef[]>): Observable<string>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SkyScrollableHostService, [null, null, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SkyScrollableHostService>;
}
